RansByteDecoder

Struct RansByteDecoder 

pub struct RansByteDecoder<Sr>
where Sr: Source<u8>,
{ /* private fields */ }
Re-export the core rANS primitives. Raw rANS decoder.

Implementations

Source

impl<Sr> RansByteDecoder<Sr>
where Sr: Source<u8>,

pub fn new(source: Sr) -> RansByteDecoder<Sr>

pub fn source(&self) -> &Sr

pub fn source_mut(&mut self) -> &mut Sr

pub fn into_source(self) -> Sr

pub fn state(&self) -> u32

pub fn check_eof(&self) -> bool

pub fn init(&mut self) -> bool

Initialize the decoder by reading the initial state from the source.

pub fn get(&self, scale_bits: u32) -> u32

Get the next symbol frequency (low scale_bits of state).

pub fn advance(&mut self, start: u32, freq: u32, scale_bits: u32) -> bool

Advance the decoder past a symbol.

Uses transactional state: computes into a local variable and only assigns to self.state after renormalization succeeds.

Equivalent to: RansDecoder::Advance(start, freq, scale_bits).

pub fn advance_symbol( &mut self, symbol: &RansByteDecSymbol, scale_bits: u32, ) -> bool

Advance using a prepared decoder symbol.